
# User Guide

```{toctree}
:caption: Get started

installation
choice-models
```

```{toctree}
:caption: Fundamentals

data-fundamentals
linear-funcs
```

```{toctree}
:caption: References

bibliography
```
